//
//  LogoStickerToolController.swift
//  Runner
//
//  Created by Danilo Pena on 15/05/20.
//  Copyright © 2020 The Chromium Authors. All rights reserved.
//

import UIKit
import PhotoEditorSDK

class AddLogoSingleton: NSObject {
    private override init() {}
    static var instance = AddLogoSingleton()
    @objc dynamic var addLogo = false
}

@available(iOS 9.0, *)
open class LogoStickerToolController: StickerToolController {
    private let podBundle = Bundle(for: SwiftPhotoEditorSdkPlugin.self) // for getting pod url
    private var buttonAddLogo = UIButton()
    private var emptyView = UIView()

    open override func viewDidLoad() {
        super.viewDidLoad()
                    
        menuViewController.hideMenu(animated: true)
        stickerSelectionController.collectionView.contentInset = UIEdgeInsets(top: 0, left: 0, bottom: 60, right: 0)
        setup()
        //Add when add logo was finished
        if UserDefaults.standard.bool(forKey: "hasAddLogo") {
            let uiView = UIView()
            uiView.backgroundColor = .white
            uiView.translatesAutoresizingMaskIntoConstraints = false
            view.addSubview(uiView)
            
            uiView.bottomAnchor.constraint(equalTo: view.bottomAnchor, constant: 0).isActive = true
            uiView.rightAnchor.constraint(equalTo: view.rightAnchor, constant: 0).isActive = true
            uiView.leftAnchor.constraint(equalTo: view.leftAnchor, constant: 0).isActive = true
            uiView.heightAnchor.constraint(equalToConstant: 60).isActive = true
            
            buttonAddLogo.setImage(UIImage(named: "ico_add_logo", in: self.podBundle, compatibleWith: nil), for: .normal)
            buttonAddLogo.translatesAutoresizingMaskIntoConstraints = false
            buttonAddLogo.addTarget(self, action: #selector(addLogo), for: .touchUpInside)
            
            uiView.addSubview(buttonAddLogo)
            
            buttonAddLogo.centerYAnchor.constraint(equalTo: uiView.centerYAnchor, constant: 0).isActive = true
            buttonAddLogo.leftAnchor.constraint(equalTo: uiView.leftAnchor, constant: 14).isActive = true
            buttonAddLogo.heightAnchor.constraint(equalToConstant: 40).isActive = true
            buttonAddLogo.widthAnchor.constraint(equalToConstant: 140).isActive = true
        }
    }
    
    open override func viewWillAppear(_ animated: Bool) {
        self.stickerSelectionController.view.alpha = 0
        UIView.animate(withDuration: 1.5) {
            self.stickerSelectionController.stickerPreviewSize = CGSize(width: (UIScreen.main.bounds.width / 2) - 40, height: 100)
            self.stickerSelectionController.view.alpha = 1
        }
    }
    
    func attLogos() {
        stickerSelectionController.stickers = createStickerSection(key: "logos", index: 1)
        stickerSelectionController.collectionView.reloadData()
    }
    
    func setup() {
        setUpStickers()
        attLogos()        
    }
    
    func makeEmptyState() -> UIView {
        let uiView = UIView(frame: view.frame)
        uiView.translatesAutoresizingMaskIntoConstraints = false
        view.addSubview(uiView)
        
        uiView.topAnchor.constraint(equalTo: view.topAnchor, constant: 20).isActive = true
        uiView.rightAnchor.constraint(equalTo: view.rightAnchor, constant: 0).isActive = true
        uiView.leftAnchor.constraint(equalTo: view.leftAnchor, constant: 0).isActive = true
        uiView.heightAnchor.constraint(equalToConstant: 400).isActive = true

        let imgView = UIImageView()
        imgView.image = UIImage(named: "ic_placeholder_empty", in: podBundle, compatibleWith: nil)
        imgView.translatesAutoresizingMaskIntoConstraints = false
        
        uiView.addSubview(imgView)
        
        imgView.topAnchor.constraint(equalTo: view.topAnchor, constant: 60).isActive = true
        imgView.centerXAnchor.constraint(equalTo: view.centerXAnchor, constant: 0).isActive = true
        imgView.heightAnchor.constraint(equalToConstant: 296).isActive = true
        imgView.widthAnchor.constraint(equalToConstant: 296).isActive = true
        
        let label = UILabel()
        label.text = "toque em \"adicionar logo\" para trazer sua logo para o Ahazou"
        label.textColor = .white
        label.numberOfLines = 0
        label.textAlignment = .center
        label.translatesAutoresizingMaskIntoConstraints = false
        
        uiView.addSubview(label)
        
        label.topAnchor.constraint(equalTo: imgView.bottomAnchor, constant: 20).isActive = true
        label.centerXAnchor.constraint(equalTo: view.centerXAnchor, constant: 0).isActive = true
        label.rightAnchor.constraint(equalTo: uiView.rightAnchor, constant: 40).isActive = true
        label.leftAnchor.constraint(equalTo: uiView.leftAnchor, constant: 40).isActive = true
        
        return uiView
    }
    
    @objc private func addLogo() {
        ImagePickerManager().pickImage(self)
    }
    
    private func createStickerSection(key: String, index: Int) -> [Sticker] {
        var images: [Sticker] = []
        let defaults = UserDefaults.standard
        if let logos = defaults.array(forKey: key) {
            for (index, logo) in logos.enumerated() {
                if let logoURL = URL(string: logo as! String) {
                    let logoSticker = Sticker(imageURL: logoURL, thumbnailURL: nil, identifier: "\(index)")
                    images.append(logoSticker)
                }
            }
            
            if logos.isEmpty {
                self.stickerSelectionController.collectionView.isHidden = true
                emptyView = makeEmptyState()
            } else {
                self.stickerSelectionController.collectionView.isHidden = false
                emptyView.removeFromSuperview()
            }
            
            return images
        }
        
        return []
    }
}
