//
//  ImagePickerManager.swift
//  flutter_plugin_android_lifecycle
//
//  Created by Danilo Pena on 28/05/20.
//

import UIKit

@available(iOS 9.0, *)
class ImagePickerManager: NSObject {
    var picker = UIImagePickerController()
    var alert = UIAlertController(title: "escolha a imagem", message: nil, preferredStyle: .actionSheet)
    var viewController: UIViewController?

    func pickImage(_ viewController: UIViewController) {
        self.viewController = viewController;

        let galleryAction = UIAlertAction(title: "galeria", style: .default){
            UIAlertAction in
            self.openGallery()
        }
        let cancelAction = UIAlertAction(title: "cancelar", style: .cancel){
            UIAlertAction in
        }

        // Add the actions
        picker.delegate = self
        alert.addAction(galleryAction)
        alert.addAction(cancelAction)
        alert.popoverPresentationController?.sourceView = self.viewController!.view
        viewController.present(alert, animated: true, completion: nil)

        openGallery()
    }
    func openGallery(){
        picker.sourceType = .photoLibrary
        self.viewController?.present(picker, animated: true, completion: nil)
    }
    
    func displaySignUpPendingAlert() -> UIAlertController {
        let alert = UIAlertController(title: " \n\n", message: "", preferredStyle: .alert)
        let activityIndicator = UIActivityIndicatorView(style: .gray)
        
        let messageFont = [NSAttributedString.Key.font: UIFont.systemFont(ofSize: 15, weight: .bold)]
        let messageAttrString = NSMutableAttributedString(string: "enviando sua logo...", attributes: messageFont)

        alert.setValue(messageAttrString, forKey: "attributedMessage")

        let cancel = UIAlertAction(title: "cancelar", style: .default) { (alertAction) in
            alert.dismiss(animated: true, completion: nil)
        }
        activityIndicator.translatesAutoresizingMaskIntoConstraints = false
        activityIndicator.isUserInteractionEnabled = false
        activityIndicator.startAnimating()
        
        alert.addAction(cancel)
        
        alert.view.addSubview(activityIndicator)
        alert.view.heightAnchor.constraint(equalToConstant: 130).isActive = true

        activityIndicator.centerXAnchor.constraint(equalTo: alert.view.centerXAnchor, constant: 0).isActive = true
        activityIndicator.bottomAnchor.constraint(equalTo: alert.view.bottomAnchor, constant: -90).isActive = true

        viewController?.present(alert, animated: true)
        return alert
    }
}

@available(iOS 9.0, *)
extension ImagePickerManager: UIImagePickerControllerDelegate, UINavigationControllerDelegate {
    func imagePickerControllerDidCancel(_ picker: UIImagePickerController) {
        picker.dismiss(animated: true, completion: nil)
    }
    
    func imagePickerController(_ picker: UIImagePickerController, didFinishPickingMediaWithInfo info: [UIImagePickerController.InfoKey : Any]) {
        if let image = info[UIImagePickerController.InfoKey.originalImage] as? UIImage {
           let resizedImage = image.aspectFittedToHeight(300.0)
           let imageData = resizedImage.pngData()
           
           let uploadImageManager = UploadImageManager()
           uploadImageManager.imageData = imageData
           
           let alert = displaySignUpPendingAlert()
           if let request = uploadImageManager.makeRequest() {
               URLSession.shared.dataTask(with: request) { (data, urlResponse, error) in
                   DispatchQueue.main.async {
                       alert.dismiss(animated: true, completion: nil)
                   }
                   if error != nil {
                       self.viewController?.showAlert(with: "ops!", message: "não conseguimos salvar sua logo. quer tentar novamente?")
                   } else {
                       if let dataNotNull = data {
                           do {
                               if let parsedDictionary = try JSONSerialization.jsonObject(with: dataNotNull, options: []) as? [String: Any] {
                                   var logos = UserDefaults.standard.array(forKey: "logos")
                                   logos?.append(parsedDictionary["url"] ?? "")
                                   UserDefaults.standard.setValue(logos, forKey: "logos")
                                   if let logoStickerController = self.viewController as? LogoStickerToolController {
                                       DispatchQueue.main.async {
                                           logoStickerController.setup()
                                       }
                                   }
                               }
                           } catch {
                               print(error.localizedDescription)
                           }
                       }
                   }
               }.resume()
           }
        }
        picker.dismiss(animated: true, completion: nil)
    }
}
